| se0_ridge | R Documentation |
Logistic ridge regression state evolution functions with no intercept
se0_ridge(mu, b, sigma, kappa, gamma, lambda, gh = NULL, prox_tol = 1e-10)
mu |
aggregate bias parameter. |
b |
parameter |
sigma |
square root of the aggregate variance of the MDYPL estimator. |
kappa |
asymptotic ratio of columns/rows of the design
matrix. |
gamma |
the square root of the limit of the variance of the linear predictor. |
lambda |
the shrinkage parameter of the logistic regression penalty
estimator. |
gh |
A list with the Gauss-Hermite quadrature nodes and
weights, as returned from |
prox_tol |
tolerance for the computation of the proximal
operator; default is |
It is assumed that the ridge penalty to the logistic regression
log-likelihood is n * lambda * sum(beta^2) / (2 * length(beta)),
where n is the sum of the binomial totals.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.